@@ -3,19 +3,20 @@ from decimal import Decimal
 from typing import Union, Type, Optional, Any, TypeVar
 
 import orjson
-import pydantic
 from dateutil.tz import gettz
+from pydantic import TypeAdapter
 
 from settings_models.doc import Setting
 from settings_models.settings.common import SettingsModel, Gates, Rates, ParkingAreas, Parksettings, CostGroups, \
     PrivacySettings, BillingSettings, Location, SupportSettings, RefsModel, GarageSettings, GarageName, Urls
-from settings_models.settings.device_keys import PairingKey, Certificate, Otp
-from settings_models.settings.enforcement import EnforcementSettings
-from settings_models.settings.gate_control import GateMode, DayMode
+from settings_models.settings.device_keys import PairingKey, CertificateType, OtpType
+from settings_models.settings.enforcement import EnforcementSettingsType
+from settings_models.settings.gate_control import GateModeType, DayModeType
 from settings_models.settings.intercom import IntercomSettings
 from settings_models.settings.io import SignalDefinitions, InputDefinitions
 
 T = TypeVar('T')
+RefsModelAdapter = TypeAdapter(RefsModel)
 
 _model_mapping = {
     "common/gates": Setting(Gates, "Has one entry for each gate of the garage."),
@@ -35,13 +36,13 @@ _model_mapping = {
     "common/support": Setting(SupportSettings),
     "common/garage_name": Setting(GarageName),
     "common/urls": Setting(Urls),
-    "gate_control/mode": Setting(GateMode, scoped=True),
-    "gate_control/day_mode": Setting(DayMode),
-    "enforcement/basic_settings": Setting(EnforcementSettings),
+    "gate_control/mode": Setting(GateModeType, scoped=True),
+    "gate_control/day_mode": Setting(DayModeType),
+    "enforcement/basic_settings": Setting(EnforcementSettingsType),
     "intercom/basic_settings": Setting(IntercomSettings),
     "device_keys/pairing": Setting(PairingKey),
-    "device_keys/cert": Setting(Certificate),
-    "device_keys/otp": Setting(Otp),
+    "device_keys/cert": Setting(CertificateType),
+    "device_keys/otp": Setting(OtpType),
     "feature_flags": Setting(dict, "A dictionary of custom values that can be used to enable or "
                                    "disable features in various places."),
     "io/signals": Setting(SignalDefinitions, "Defines the available signals."),
@@ -49,11 +50,11 @@ _model_mapping = {
 }
 
 
-def _get_type(key: str, custom_type: Optional[Type[T]]) -> Type[T]:
+def _get_type(key: str, custom_type: Optional[Type[T]]) -> TypeAdapter[T]:
     if custom_type:
-        return custom_type
+        return TypeAdapter(custom_type)
     if "/refs/" in key:
-        return RefsModel
+        return RefsModelAdapter
     if key not in _model_mapping:
         raise KeyError(f"No model for setting {key} found")
     return _model_mapping[key].settings_model
@@ -102,7 +103,7 @@ def parse_setting_from_obj(key: str, value: Any, custom_type: Optional[Type[T]]
     :raises: ValueError if validation of setting fails
     """
     target_type = _get_type(key, custom_type)
-    obj = pydantic.parse_obj_as(target_type, value)
+    obj = target_type.validate_python(value)
     if not custom_type:
         _special_validation(key, obj)
     return obj
@@ -127,7 +128,7 @@ def parse_setting(key: str, value: Union[str, bytes], custom_type: Optional[Type
 
 def _default(obj):
     if isinstance(obj, SettingsModel):
-        return obj.dict()
+        return obj.model_dump()
     if isinstance(obj, Decimal):
         return str(obj)
     raise TypeError
