@@ -1,13 +1,15 @@
 from datetime import datetime
-from enum import Enum
+from enum import StrEnum
 from typing import Dict, List, Optional, Union
-from pydantic import root_validator, validator, constr
 
-from settings_models.validators import uuid_validator, domain_validator, account_id_range_validator
+from pydantic import constr, model_validator, AfterValidator
+from typing_extensions import Annotated
+
 from settings_models._combat import SettingsModel, Field
+from settings_models.validators import uuid_validator, domain_validator, account_id_range_validator
 
 
-class GateType(str, Enum):
+class GateType(StrEnum):
     """
     Types of a gate. This defines the usage and the general behavior of a gate
     """
@@ -23,7 +25,7 @@ class GateType(str, Enum):
 
     door = "door"
     """
-    Door: Gate without LPR where people can walk into the parking lot. 
+    Door: Gate without LPR where people can walk into the parking lot.
     No check-in or check-out, only access check
     """
 
@@ -35,7 +37,7 @@ class GateType(str, Enum):
 
     transit_custom = "transit_custom"
     """
-    Gates with custom behavior. These gates might or might not have a barrier. Examples are: 
+    Gates with custom behavior. These gates might or might not have a barrier. Examples are:
       - Passage check gates (permanent parkers must pass this gate or gets fined)
       - Gate with shortterm count check (e.g. only 10 shortterm parkers are allowed at the same time)
       - automatic gates (e.g. exit of restricted subarea)
@@ -48,16 +50,15 @@ class GateType(str, Enum):
     independently, e.g. perma open
     """
 
-    multilane = "multilane"
+    check_in_out = "check_in_out"
     """
-    Gates where multiple vehicles can pass at the same (either in parallel or in opposite direction).
-    This is only allowed in Freeflow mode and with no user interaction (e.g. display)
+    Freeflow entries, exits or bidirectional lanes without hardware. We only checkin or checkout license plates here.
     """
 
-    transit_multilane = "transit_multilane"
+    transit_passthrough = "transit_passthrough"
     """
-    Multilane type of transit_custom (multiple vehicles can pass at the same). Only allowed for automatically setting
-    something for passing vehicles (e.g. changing rate) 
+    Transit lanes which are only used to detect passing license plates,
+    e.g. to change parking rate or to check if someone parked in the correct area
     """
 
 
@@ -74,11 +75,16 @@ class Gate(SettingsModel):
     """
     Definition of a Gate
     """
-    gate: constr(min_length=1, max_length=126, regex=r"^[a-z0-9\-_]+$") = \
+    gate: constr(min_length=1, max_length=126, pattern=r"^[a-z0-9\-_]+$") = \
         Field(..., description="Technical name of gate")
     name: str = Field(..., description="Name for UIs", max_length=126)
     type: GateType = Field(..., description="Type of the gate. Defines the usage and general behavior")
-    opposite_gate: Optional[str] = Field(None, description="Name of the opposite gate for bidirectional gates")
+    opposite_gate: Optional[str] = Field(default=None, description="Name of the opposite gate for bidirectional gates")
+    is_wide: Optional[bool] = Field(default=None,
+                                    description="This field in the gate settings model indicates whether the gate is "
+                                                "wide. For gates of type entry and exit in Freeflow mode, the value "
+                                                "must be either true or false. For all other gate types, the value must "
+                                                "be null.")
 
 
 class Rate(SettingsModel):
@@ -92,7 +98,7 @@ class Rate(SettingsModel):
     id_validator = uuid_validator("id")
 
 
-class CommandCostEntryTypes(str, Enum):
+class CommandCostEntryTypes(StrEnum):
     """
     Types of command cost entries: Those are used to cost entries in a parking session, e.g. via parksettings
     """
@@ -146,45 +152,57 @@ class CostEntryData(SettingsModel):
     """
     entry_type: CommandCostEntryTypes = Field(..., description="Cost entry command type")
     value: Optional[Union[int, str, Dict[str, Optional[datetime]]]] = (
-        Field(None, description="value: Dependent on entry_type it's an int, a str or None"))
-    group: Optional[str] = Field(None, description="Cost group the command cost entry is applied on. None for global")
+        Field(default=None, description="value: Dependent on entry_type it's an int, a str or None"))
+    group: Optional[str] = Field(default=None, description="Cost group the command cost entry is applied on. None for "
+                                                           "global")
     account_id: str = Field(..., description="The account_id the generated booked cost entry will be booked at. "
                                              "It is an integer between 0 and 3999 formatted as string")
 
     account_id_validator = account_id_range_validator("account_id", 0, 3999)
 
     # Not used in settings, set by service applying the command cost entry (e.g. access service)
-    source: Optional[str]
-    source_id: Optional[str]
-    idempotency_key: Optional[str]
+    source: Optional[str] = Field(default=None, description="Source of cost entry (usually service name)")
+    source_id: Optional[str] = Field(default=None, description="Id to get information about cost entry in source "
+                                                               "service")
+    idempotency_key: Optional[str] = Field(default=None, description="Legacy field for idempotency key")
 
-    @root_validator(skip_on_failure=True)
+    @model_validator(mode="before")
     def data_validation(cls, values):
         if values.get("entry_type") in [CommandCostEntryTypes.static_cost, CommandCostEntryTypes.pending_static_cost,
                                         CommandCostEntryTypes.amount_validation, CommandCostEntryTypes.time_validation,
                                         CommandCostEntryTypes.payment]:
-            if not isinstance(values["value"], int) or values["value"] <= 0:
+            if not isinstance(values.get("value"), int) or values.get("value") <= 0:
                 raise ValueError("value must be an integer greater 0")
         elif values.get("entry_type") in [CommandCostEntryTypes.rate_change, CommandCostEntryTypes.rate_validation,
                                           CommandCostEntryTypes.partial_rate_change]:
-            values["value"] = str(values["value"])
+            values["value"] = str(values.get("value"))
         if values.get("entry_type") not in [CommandCostEntryTypes.payment, CommandCostEntryTypes.cancel_remaining_costs,
                                             CommandCostEntryTypes.payoff_costs, CommandCostEntryTypes.free_timerange]:
-            if values["group"] is None:
+            if values.get("group") is None:
                 raise ValueError("group must be set")
         elif values.get("entry_type") in [CommandCostEntryTypes.cancel_remaining_costs,
                                           CommandCostEntryTypes.payoff_costs]:
-            if values["group"] is not None:
+            if values.get("group") is not None:
                 raise ValueError("group must NOT be set")
         elif values.get("entry_type") == CommandCostEntryTypes.free_timerange:
-            values["value"] = dict(entry_start=values["value"].get("entry_start"),
-                                   entry_end=values["value"].get("entry_end"))
-            if values["group"] is None:
+            values["value"] = dict(entry_start=values.get("value", {}).get("entry_start"),
+                                   entry_end=values.get("value", {}).get("entry_end"))
+            if values.get("group") is None:
                 raise ValueError("group must be set")
         return values
 
 
-class ShorttermLimitType(str, Enum):
+def cost_entry_validator(cost_entry):
+    if cost_entry.entry_type in (CommandCostEntryTypes.partial_rate_change, CommandCostEntryTypes.payment,
+                                 CommandCostEntryTypes.cancel_remaining_costs, CommandCostEntryTypes.payoff_costs):
+        raise ValueError(f"{cost_entry.entry_type} is not allowed as cost entry")
+    return cost_entry
+
+
+CostEntryField = List[Annotated[CostEntryData, AfterValidator(cost_entry_validator)]]
+
+
+class ShorttermLimitType(StrEnum):
     """
     Types of shortterm limits
     """
@@ -208,45 +226,31 @@ class ParkingArea(SettingsModel):
     id: str = Field(..., description="Id of the parking area. UUID string in canonical textual representation")
     name: str = Field(..., description="Name for UIs", max_length=126)
     gates: List[str] = Field(..., description="Gates in this physical area (only types entry, exit, bidirectional or "
-                                              "transit_barrier/transit_access_check)", min_items=1)
+                                              "transit_barrier/transit_access_check)", min_length=1)
     shortterm_gates: List[str] = Field(..., description="Gates in this physical area (only types entry, exit, "
                                                         "bidirectional or transit_barrier/transit_access_check), where "
                                                         "shortterm parkers are allowed")
-    default_cost_entries: List[CostEntryData] = Field(..., description="Default cost entries added on entry in this "
-                                                                       "parking area for unknown parkers")
-    pay_per_use_cost_entries: Optional[List[CostEntryData]] = \
-        Field(None, description="Default cost entries added on entry in this parking area for pay-per-use parkers. None"
-                                " is fallback to default_cost_entries")
+    default_cost_entries: CostEntryField = Field(..., description="Default cost entries added on entry "
+                                                                  "in this parking area for unknown parkers")
+    pay_per_use_cost_entries: Optional[CostEntryField] = \
+        Field(default=None, description="Default cost entries added on entry in this parking area for pay-per-use "
+                                        "parkers. None is fallback to default_cost_entries")
     shortterm_limit_type: ShorttermLimitType = Field(..., description="Type of shortterm limit")
     shortterm_limit: int = Field(..., description="Limit value in this area. Compared to value specified in "
                                                   "shortterm_limit_type", ge=0)
-    number_of_parking_spaces: Optional[int] = Field(None, description="Number of parking spaces in this area. None if "
-                                                                      "not specified", ge=0)
+    number_of_parking_spaces: Optional[int] = Field(default=None, description="Number of parking spaces in this area. "
+                                                                              "None if not specified", ge=0)
 
     id_validator = uuid_validator("id")
 
-    @validator('default_cost_entries', each_item=True)
-    def cost_entry_validator(cls, cost_entry):
-        if cost_entry.entry_type in [CommandCostEntryTypes.partial_rate_change, CommandCostEntryTypes.payment,
-                                     CommandCostEntryTypes.cancel_remaining_costs, CommandCostEntryTypes.payoff_costs]:
-            raise ValueError(f"{cost_entry.entry_type} is not allowed as default cost entry in parking area")
-        return cost_entry
-
-    @validator('pay_per_use_cost_entries', each_item=True)
-    def pay_per_use_cost_entries_validator(cls, cost_entry):
-        if cost_entry.entry_type in [CommandCostEntryTypes.partial_rate_change, CommandCostEntryTypes.payment,
-                                     CommandCostEntryTypes.cancel_remaining_costs, CommandCostEntryTypes.payoff_costs]:
-            raise ValueError(f"{cost_entry.entry_type} is not allowed as pay per use cost entry in parking area")
-        return cost_entry
-
-    @root_validator(skip_on_failure=True)
+    @model_validator(mode="after")
     def validate_shortterm_gates_in_gates(cls, values):
         """
         check if all shortterm gates are in gates
         """
-        if not all(gate in values["gates"] for gate in values["shortterm_gates"]):
+        if not all(gate in values.gates for gate in values.shortterm_gates):
             raise ValueError("All shortterm gates must be in gates")
-        if len(values["shortterm_gates"]) == 0 and len(values["default_cost_entries"]) > 0:
+        if len(values.shortterm_gates) == 0 and len(values.default_cost_entries) > 0:
             raise ValueError("If no shortterm gates are defined, no default cost entries are allowed")
         return values
 
@@ -259,19 +263,12 @@ class Parksetting(SettingsModel):
     id: str = Field(..., description="Id of the parksetting. UUID string in canonical textual representation")
     name: str = Field(..., description="Name for UIs", max_length=126)
     gates: List[str] = Field(..., description="Gates this parksetting is valid for (only types entry, exit, "
-                                              "bidirectional or transit_barrier/transit_access_check", min_items=1)
-    default_cost_entries: List[CostEntryData] = Field(..., description="Default cost entries added on entry. "
-                                                                       "Empty list is free.")
+                                              "bidirectional or transit_barrier/transit_access_check", min_length=1)
+    default_cost_entries: CostEntryField = Field(..., description="Default cost entries added on entry. "
+                                                                  "Empty list is free.")
 
     id_validator = uuid_validator("id")
 
-    @validator('default_cost_entries', each_item=True)
-    def cost_entry_validator(cls, cost_entry):
-        if cost_entry.entry_type in [CommandCostEntryTypes.partial_rate_change, CommandCostEntryTypes.payment,
-                                     CommandCostEntryTypes.cancel_remaining_costs, CommandCostEntryTypes.payoff_costs]:
-            raise ValueError(f"{cost_entry.entry_type} is not allowed as default cost entry in parksetting")
-        return cost_entry
-
 
 class CostGroup(SettingsModel):
     """
@@ -286,21 +283,21 @@ class CostGroup(SettingsModel):
 
     account_id_validator = account_id_range_validator("account_id", 0, 999)
 
-    @root_validator(skip_on_failure=True)
+    @model_validator(mode="after")
     def data_validation(cls, values):
         """
         check if cost group id prefix matches account_id range
         """
         # validator is run before root_validator, so int cast is safe
-        if int(values["account_id"]) < 100 and not values["id"].startswith("parking_"):
+        if int(values.account_id) < 100 and not values.id.startswith("parking_"):
             raise ValueError("account_ids from 0 to 99 must have cost_group id parking_*")
-        if 100 <= int(values["account_id"]) < 200 and not values["id"].startswith("fine_"):
+        if 100 <= int(values.account_id) < 200 and not values.id.startswith("fine_"):
             raise ValueError("account_ids from 100 to 199 must have cost_group id fine_*")
-        if 200 <= int(values["account_id"]) < 300 and not values["id"].startswith("ev-charging_"):
+        if 200 <= int(values.account_id) < 300 and not values.id.startswith("ev-charging_"):
             raise ValueError("account_ids from 200 to 299 must have cost_group id ev-charging_*")
-        if 300 <= int(values["account_id"]) < 400 and not values["id"].startswith("honest-payment_"):
+        if 300 <= int(values.account_id) < 400 and not values.id.startswith("honest-payment_"):
             raise ValueError("account_ids from 300 to 399 must have cost_group id honest-payment_*")
-        if 400 <= int(values["account_id"]) < 500 and not values["id"].startswith("misc_"):
+        if 400 <= int(values.account_id) < 500 and not values.id.startswith("misc_"):
             raise ValueError("account_ids from 400 to 499 must have cost_group id misc_*")
         return values
 
@@ -309,13 +306,13 @@ class PrivacyTime(SettingsModel):
     """
     Model to define timespan as used in privacy settings. At least one of minutes, hours, days must > 0
     """
-    minutes: int = Field(0, ge=0, description="Miuntes of timespan. Must be >= 0 if given")
-    hours: int = Field(0, ge=0, description="Hours of timespan. Must be >= 0 if given")
-    days: int = Field(0, ge=0, description="Days of timespan. Must be >= 0 if given")
+    minutes: int = Field(default=0, ge=0, description="Miuntes of timespan. Must be >= 0 if given")
+    hours: int = Field(default=0, ge=0, description="Hours of timespan. Must be >= 0 if given")
+    days: int = Field(default=0, ge=0, description="Days of timespan. Must be >= 0 if given")
 
-    @root_validator(skip_on_failure=True)
+    @model_validator(mode="after")
     def data_validation(cls, values):
-        if values["minutes"] == 0 and values["hours"] == 0 and values["days"] == 0:
+        if values.minutes == 0 and values.hours == 0 and values.days == 0:
             raise ValueError("At least one of minutes, hours or days must be > 0")
         return values
 
@@ -344,13 +341,13 @@ class AddressModel(SettingsModel):
 
     street: str = Field(..., description="Street name")
     number: str = Field(..., description="House number")
-    floor: Optional[str] = Field(None, description="Floor number or name")
-    door: Optional[str] = Field(None, description="Door number or name")
-    supplements: Optional[str] = Field(None, description="Additional description of address")
+    floor: Optional[str] = Field(default=None, description="Floor number or name")
+    door: Optional[str] = Field(default=None, description="Door number or name")
+    supplements: Optional[str] = Field(default=None, description="Additional description of address")
 
     city: str = Field(..., description="City")
     zip_code: str = Field(..., description="Zip code")
-    state: Optional[str] = Field(None, description="State")
+    state: Optional[str] = Field(default=None, description="State")
     country: str = Field(..., description="Country")
 
 
@@ -377,22 +374,22 @@ class SupportSettings(SettingsModel):
     (cannot enter door, cannot pay, ...)
     """
     name: str = Field(..., description="Name of the person/entity responsible for support, e.g. provider")
-    address: Optional[AddressModel] = Field(None, description="Address for written support letters")
-    phone_number: Optional[constr(min_length=3, max_length=32, regex=r"^\+[0-9 ]+$")] = \
-        Field(None, description="Phone number for support (not emergency calls)")
+    address: Optional[AddressModel] = Field(default=None, description="Address for written support letters")
+    phone_number: Optional[constr(min_length=3, max_length=32, pattern=r"^\+[0-9 ]+$")] = \
+        Field(default=None, description="Phone number for support (not emergency calls)")
     email_address: Optional[constr(min_length=3, max_length=254,
-                                   regex=r"^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+$")] = \
-        Field(None, description="Email address for support")
-    website: Optional[constr(min_length=3, max_length=1022)] = Field(None, description="Website for support")
+                                   pattern=r"^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+$")] = \
+        Field(default=None, description="Email address for support")
+    website: Optional[constr(min_length=3, max_length=1022)] = Field(default=None, description="Website for support")
 
-    @root_validator(skip_on_failure=True)
+    @model_validator(mode="after")
     def data_validation(cls, values):
-        if (values["address"] or values["phone_number"] or values["email_address"] or values["website"]) is None:
+        if (values.address or values.phone_number or values.email_address or values.website) is None:
             raise ValueError("At least one of address, phone_number, email_address or website must be given")
         return values
 
 
-class GarageModes(str, Enum):
+class GarageModes(StrEnum):
     """
     Garage modes
     """
@@ -416,11 +413,12 @@ class GarageSettings(SettingsModel):
     """
     mode: GarageModes = Field(..., description="General parking lot mode, e.g. freeflow. This field is more for "
                                                "information in UI and setup than for real technical use.")
-    honest_payment_enabled: bool = Field(False, description="If honest payments are allowed")
-    enforcement_enabled: bool = Field(False, description="If unpaid parking sessions can be enforced")
-    payment_possible: bool = Field(False, description="If any parking system payments (Kiosk, PayApp,...) are possible")
+    honest_payment_enabled: bool = Field(default=False, description="If honest payments are allowed")
+    enforcement_enabled: bool = Field(default=False, description="If unpaid parking sessions can be enforced")
+    payment_possible: bool = Field(default=False, description="If any parking system payments (Kiosk, PayApp,...) are "
+                                                              "possible")
 
-    @root_validator(skip_on_failure=True, pre=True)
+    @model_validator(mode="before")
     def data_validation(cls, values):
         if not isinstance(values, dict):
             return values
@@ -448,9 +446,9 @@ class GarageName(SettingsModel):
     Names of Garage (directly set in Garage UI / iam)
     """
     name: str = Field(..., description="Name of Garage for UIs and end users", max_length=126)
-    technical_name: constr(min_length=3, max_length=63, regex=r"^[a-z0-9\-]+$") = \
+    technical_name: constr(min_length=3, max_length=63, pattern=r"^[a-z0-9\-]+$") = \
         Field(..., description="Technical/internal name of garage")
-    slug: constr(min_length=3, max_length=126, regex=r"^[a-zA-Z0-9\-_]+$") = \
+    slug: constr(min_length=3, max_length=126, pattern=r"^[a-zA-Z0-9\-_]+$") = \
         Field(..., description="Shortname of Garage used in URLs")
 
 
