@@ -18,7 +18,7 @@ class PairingKey(SettingsModel):
     created_at_validator = timezone_validator("created_at")
 
 
-class _Certificate(SettingsModel):
+class Certificate(SettingsModel):
     """
     Certificate for secure communication with kiosk devices
     """
@@ -27,7 +27,7 @@ class _Certificate(SettingsModel):
     fingerprint: str = Field(..., description="SHA256 certificate fingerprint")
 
 
-class _Otp(SettingsModel):
+class Otp(SettingsModel):
     """
     OTP secret for authentication on the kiosk
     """
@@ -35,7 +35,7 @@ class _Otp(SettingsModel):
     interval: int = Field(..., description="OTP interval in seconds")
 
 
-Otp = Optional[_Otp]
-Otp.__doc__ = _Otp.__doc__
-Certificate = Optional[_Certificate]
-Certificate.__doc__ = _Certificate.__doc__
+OtpType = Optional[Otp]
+OtpType.__doc__ = Otp.__doc__
+CertificateType = Optional[Certificate]
+CertificateType.__doc__ = Certificate.__doc__
