@@ -1,11 +1,11 @@
-from enum import Enum
+from enum import StrEnum
 from typing import Optional
 
 from settings_models._combat import SettingsModel, Field
 from settings_models.validators import hhmm_validator
 
 
-class _GateMode(str, Enum):
+class GateMode(StrEnum):
     """
     How the gate should behave
     """
@@ -15,19 +15,19 @@ class _GateMode(str, Enum):
     standard = "standard"
 
 
-class _DayMode(SettingsModel):
+class DayMode(SettingsModel):
     """
     If day mode (everyone can enter) is enabled and at what time of day
     """
     enabled: bool
-    start: str = Field("00:00", description="Start of day mode in format HH:MM local time")
-    end: str = Field("00:00", description="End of day mode in format HH:MM local time")
+    start: str = Field(default="00:00", description="Start of day mode in format HH:MM local time")
+    end: str = Field(default="00:00", description="End of day mode in format HH:MM local time")
 
     start_validator = hhmm_validator("start")
     end_validator = hhmm_validator("end")
 
 
-GateMode = Optional[_GateMode]
-GateMode.__doc__ = _GateMode.__doc__
-DayMode = Optional[_DayMode]
-DayMode.__doc__ = _DayMode.__doc__
+GateModeType = Optional[GateMode]
+GateModeType.__doc__ = GateMode.__doc__
+DayModeType = Optional[DayMode]
+DayModeType.__doc__ = DayMode.__doc__
