@@ -102,6 +102,10 @@ class ParsingTests(TestCase):
         res = parse_setting("common/garage_settings", setting_str)
         self.assert_result('{"mode": "barrier", "honest_payment_enabled": false, "enforcement_enabled": false, '
                            '"payment_possible": true}', dump_setting(res))
+        setting_str = '{"mode": "barrier_bypass"}'
+        res = parse_setting("common/garage_settings", setting_str)
+        self.assert_result('{"mode": "barrier_bypass", "honest_payment_enabled": false, "enforcement_enabled": false, '
+                           '"payment_possible": false}', dump_setting(res))
 
     def test_location(self):
         setting_str = '{"name": "Garage", "street": "Garagestreet", "number": "12c", "floor": "2H", "door": "7a", ' \
@@ -148,7 +152,7 @@ class ParsingTests(TestCase):
 
     def test_enforcement_basic_settings(self):
         setting_str = '{"strictness": 2, "payment_deadline_hours": 48, "enabled": true, ' \
-                      '"last_edited": "2023-03-08T08:48:37.184000"}'
+                      '"ai_enabled": true, "last_edited": "2023-03-08T08:48:37.184000"}'
         res = parse_setting("enforcement/basic_settings", setting_str)
         self.assert_result(setting_str, dump_setting(res))
 
