@@ -7,11 +7,12 @@ from settings_models.serialization import dump_setting
 
 class TestCase(unittest.TestCase):
     def remove_nones(self, d):
-        for k, v in list(d.items()):
-            if isinstance(v, dict):
-                self.remove_nones(v)
-            elif v is None:
-                del d[k]
+        if isinstance(d, dict):
+            for k, v in list(d.items()):
+                if isinstance(v, dict):
+                    self.remove_nones(v)
+                elif v is None:
+                    del d[k]
         return d
 
     @staticmethod
@@ -23,7 +24,7 @@ class TestCase(unittest.TestCase):
     def assert_result(self, res, gt):
         res = self.remove_nones(self.load_if_json(res))
         gt = self.remove_nones(self.load_if_json(gt))
-        self.assertDictEqual(res, gt)
+        self.assertEqual(res, gt)
 
     def assert_not_result(self, res, gt):
         res = self.remove_nones(self.load_if_json(res))
